
# This file was generated by 'versioneer.py' (0.29) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2024-01-04T13:02:14+0100",
 "dirty": true,
 "error": null,
 "full-revisionid": "6ea4e3eb2a4df6f645f705e9accd2f7513565418",
 "version": "0.4.4"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
